@@ -25,11 +25,11 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.62 2007/02/11 03:42:23 bowkenken Exp $
+* $Id: amenu.c,v 1.64 2007/03/17 22:28:31 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
-* ưޡ
+* (ưޡ)
 ***************************************************************/
 
 #define	AMENU_C
@@ -644,10 +644,12 @@ void	set_menu_auto_mark( menu_t **dflt )
 	long	left_max_len;
 	menu_t	*p;
 	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN * 2 + 16 + 1];
+	char	key;
 	long	i, k;
 
 	p = ls_menu_auto_mark;
 	k = 0;
+	key = 'A';
 
 	str_nz_cpy( p[k].path, "/auto mark", MENU_PATH_MAX_LEN );
 	str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
@@ -686,22 +688,39 @@ void	set_menu_auto_mark( menu_t **dflt )
 		if( i == auto_mark_cur_n )
 			*dflt = &(p[k]);
 
+		if( (i != 0) && ((i % AUTO_MARK_N_PER_PAGE) == 0) ){
+			str_nz_cpy( p[k].path, "/auto mark/--",
+					MENU_PATH_MAX_LEN );
+			str_nz_cpy( p[k].kind, "<PageSeparator>",
+					MENU_KIND_MAX_LEN );
+			p[k].accel_key = '\0';
+			p[k].short_key[0] = '\0';
+			p[k].n_msg = N_MSG_NULL;
+			p[k].msg[0] = '\0';
+			p[k].call_back = NULL;
+			p[k].arg = NULL;
+			p[k].flg = FLG_NULL;
+			k++;
+
+			key = 'A';
+		}
+
 		sprintf( buf, "%*s%s%s",
 				(int)left_max_len,
 				get_msg_ttl_auto_mark_info( i ),
 				STR_TTL_AUTO_MARK_SPLIT_NAME,
-
 				get_msg_ttl_auto_mark_hint( i ) );
 
 		sprintf( p[k].path, "/auto mark/%ld", i );
 		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
-		p[k].accel_key = (char)('A' + i);
+		p[k].accel_key = key;
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, buf, MENU_MSG_MAX_LEN );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
 		k++;
+		key++;
 
 		sprintf( p[k].path, "%s/exec", p[kk].path );
 		str_nz_cpy( p[k].kind, "<Item>", MENU_KIND_MAX_LEN );
@@ -2009,7 +2028,9 @@ char	*cb_menu_auto_mark_edit_macro_bind( menu_t **pp, menu_t **dflt )
 
 	x = str_len_draw( msg_cmd );
 	y = get_max_line() - 1;
-	if( game_gets( x, y, buf_cmd, MACRO_MAX_LEN, TRUE ) ){
+	str_nz_cpy( buf_cmd, cmd, MACRO_MAX_LEN );
+
+	if( game_gets( x, y, msg_cmd, buf_cmd, MACRO_MAX_LEN, TRUE ) ){
 		long	len;
 
 		/* βԤ */
