@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.h,v 1.9 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: amenu.h,v 1.10 2007/03/17 22:28:32 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_H
@@ -36,7 +36,9 @@
 ***************************************************************/
 
 /* ưޡκ */
-#define	AUTO_MARK_MAX_N	16
+#define	AUTO_MARK_N_PER_PAGE	16
+#define	AUTO_MARK_PAGE_N	10
+#define	AUTO_MARK_MAX_N	(AUTO_MARK_N_PER_PAGE * AUTO_MARK_PAGE_N)
 
 /* ȥκʸ */
 #define	MSG_TTL_AUTO_MARK_MAX_LEN	128
