@@ -150,6 +150,10 @@ long	calc_resi( rate_t resi, long n );
 long	get_generalist_lev( chr_t *chr );
 long	get_specialist_lev( chr_t *chr );
 abl_kind_t	get_specialist_abl( chr_t *chr );
+chr_dir_idx_t	get_chr_dir_idx( chr_t *chr );
+void	sort_all_chr();
+void	sort_chr( chr_t *head, chr_t *chr );
+chr_t	*get_sort_chr_head( void );
 long	add_hp( chr_t *chr, long n, bool_t flg_vfx, bool_t flg_force );
 long	add_mp( chr_t *chr, long n, bool_t flg_vfx );
 rate_t	add_resi( chr_t *chr, resi_kind_t kind, rate_t n, bool_t flg_vfx );
