@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.105 2007/02/03 00:10:00 bowkenken Exp $
+* $Id: chr.h,v 1.106 2007/03/18 03:06:32 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -337,12 +337,14 @@ typedef struct {
 
 /* ٥뤫иͤ׻Υǡ */
 typedef struct {
-	long	mul_lev, add_lev;
+	rate_t	mul_lev;
+	long	add_lev;
 } lev_to_exp_t;
 
 /* ٥뤫ͤ׻Υǡ */
 typedef struct {
-	long	mul_lev, add_lev;
+	rate_t	mul_lev;
+	long	add_lev;
 } lev_to_val_t;
 
 /***************************************************************
