@@ -42,7 +42,6 @@ void	draw_map( long map_x, long map_y, long dx, long dy );
 void	redraw_map( void );
 void	wipe_map( void );
 void	force_redraw_map( void );
-void	draw_chr( chr_t *chr );
 void	draw_party( void );
 void	draw_mbr( mbr_t *p );
 void	draw_square( void );
@@ -50,6 +49,9 @@ void	draw_all_mnstr( void );
 void	draw_mnstr( mnstr_t *p );
 void	draw_all_pet( void );
 void	draw_pet( pet_t *p );
+void	draw_chr( chr_t *chr );
+void	set_flg_update_chr( long mapX, long mapY, bool_t flg );
+bool_t	get_flg_update_chr( long mapX, long mapY );
 void	draw_door( long dr_n );
 void	draw_item( item_t *p );
 void	draw_trap( trap_t *p );
@@ -92,7 +94,11 @@ void	vfx_arw_mul_line(
 void	vfx_num( chr_t *p, long n );
 void	draw_lev_up( long map_x, long map_y, long n, chr_t *chr );
 void	draw_num( long map_x, long map_y, long n, chr_t *chr );
-void	draw_blast( long map_x, long map_y, blast_t *p, char *str );
+void	draw_blast(
+	chr_kind_t kind,
+	long map_x, long map_y,
+	blast_t *p, char *str
+);
 void	draw_request( request_t *req );
 void	draw_mbr_data_all( mbr_t *org, mbr_t *mbr, long page_n );
 void	draw_mbr_data( mbr_t *org, mbr_t *mbr, data_n_t n, bool_t flg_rev );
@@ -115,7 +121,12 @@ void	draw_edit_class(
 bool_t	gets_class_name( char *name );
 bool_t	gets_auto_mark_info( char *name );
 bool_t	gets_auto_mark_hint( char *name );
-bool_t	game_gets( long x, long y, char *s, long len, bool_t flg_pick );
+bool_t	game_gets(
+	long x, long y,
+	char *ttl, char *s, long len,
+	bool_t flg_pick
+);
+void	game_gets_gui_sub( char *ttl, char *s, long len );
 void	pick_cntrl_str( char *s );
 void	set_crsr( long x, long y );
 void	reset_crsr( void );
@@ -138,7 +149,8 @@ char	*get_reg_macro( void );
 void	set_reg_macro( bool_t flg );
 void	reg_macro( long c );
 long	get_key( bool_t flg_clr_key_buf );
-long	get_key_sub( bool_t flg_clr_key_buf );
+long	get_key_sub_1( bool_t flg_clr_key_buf );
+long	get_key_sub_2( bool_t flg_clr_key_buf );
 long	get_key_x68k( bool_t flg_clr_key_buf );
 long	get_key_dos( void );
 long	get_key_half_wait( void );
