@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.99 2007/02/18 22:49:15 bowkenken Exp $
+* $Id: dun.c,v 1.101 2007/03/17 23:38:58 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -332,6 +332,13 @@ void	up_dun( long d )
 	if( dun.lev < -DUN_MAX_LEV_BASE )
 		dun.lev = -DUN_MAX_LEV_BASE;
 
+	if( g_flg_init ){
+		if( get_flg_no_save() )
+			menu_save_n( TRUE, SAVE_N_AUTO );
+		else
+			menu_save_n( FALSE, SAVE_N_AUTO );
+	}
+
 	if( sgn_l( dun.lev ) >= +1 ){
 		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_FLOOR,
 				labs( dun.lev ) );
@@ -2182,10 +2189,13 @@ void	set_map_total_obj( long x, long y, long dx, long dy )
 	char	mjr, mnr;
 	flg_map_t	flg;
 	long	dep;
-	curs_attr_n_t	attr_n;
+	curs_attr_n_t	attr_n, attr_n_item, attr_n_trap, attr_n_sanctuary;
 	curs_attr_t	*attr_dflt;
 
 	attr_n = CURS_ATTR_N_MAP_ITEM;
+	attr_n_item = CURS_ATTR_N_MAP_ITEM;
+	attr_n_trap = CURS_ATTR_N_MAP_MNSTR;
+	attr_n_sanctuary = CURS_ATTR_N_MAP_NPC;
 	attr_dflt = get_curs_attr();
 
 	for( i = 0; i < dy; i++ ){
@@ -2219,6 +2229,16 @@ void	set_map_total_obj( long x, long y, long dx, long dy )
 			dun.map.total.mjr[yy][xx] = mjr;
 			dun.map.total.mnr[yy][xx] = mnr;
 			dun.map.total.flg[yy][xx] = FLG_NULL;
+			if( mjr == FACE_MJR_TRAP ){
+				if( mnr == FACE_MNR_TRAP_SANCTUARY ){
+					attr_n = attr_n_sanctuary;
+				} else {
+					attr_n = attr_n_trap;
+				}
+			} else {
+				attr_n = attr_n_item;
+			}
+
 			dun.map.attr[yy][xx] = attr_dflt[attr_n];
 		}
 	}
