@@ -59,6 +59,7 @@ bool_t	load_game_conf_menu_line(
 	FILE *fp, const ver_t *ver, bool_t flg_err_exit,
 	char *id
 );
+void	back_up_game_conf( void );
 bool_t	save_game_conf( void );
 bool_t	save_game_conf_ver_1( const ver_t *ver );
 bool_t	save_game_conf_scroll( FILE *fp, const ver_t *ver );
@@ -294,8 +295,12 @@ bool_t	load_game_data_c( FILE *fp, char *c );
 bool_t	load_game_data_skip_c( FILE *fp, char c, bool_t flg_draw );
 bool_t	load_game_data_skip_token( FILE *fp, rc_token_t c, bool_t flg_draw );
 bool_t	save_game_data( bool_t flg_txt, long n );
+bool_t	save_game_data_sub( bool_t flg_txt, long n );
 bool_t	save_game_data_ver_1( const ver_t *ver, bool_t flg_txt, long n );
 bool_t	save_game_data_cnf_ver_1( const ver_t *ver, long n );
+bool_t	save_game_data_dun_lev_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	save_game_data_turn_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
