@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.78 2007/02/04 18:50:59 bowkenken Exp $
+* $Id: gmain.c,v 1.82 2007/03/17 21:57:07 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -73,15 +73,15 @@ struct termio	pre_tbuf;
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUg:S:k:e:s:p:md:Vh"
+#define	STR_OPT	"GCUD:S:k:e:s:p:md:Vh"
 
 #if	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
 	{ "gui",           no_argument,       NULL, 'G' },
 	{ "cui",           no_argument,       NULL, 'C' },
 	{ "gui-and-cui",   no_argument,       NULL, 'U' },
-	{ "sel-graph-dir", required_argument, NULL, 'g' },
-	{ "graph-scale",   required_argument, NULL, 'S' },
+	{ "sel-graph-dir", required_argument, NULL, 'D' },
+	{ "map-scale",     required_argument, NULL, 'S' },
 	{ "clear-key-buf", required_argument, NULL, 'k' },
 	{ "echo-key",      required_argument, NULL, 'e' },
 	{ "use-curses",    required_argument, NULL, 's' },
@@ -104,9 +104,9 @@ char	str_usage[] = {
 	"  -G, --gui                set GUI mode\n"
 	"  -C, --cui                set CUI mode\n"
 	"  -U, --gui-and-cui        set GUI and CUI mode\n"
-	"  -g, --sel-graph-dir      select graphic directory\n"
+	"  -D, --sel-graph-dir=DIR  select graphic directory\n"
 	"                             graphic directory\n"
-	"  -S, --graph-scale        set graphic scale\n"
+	"  -S, --map-scale          set scale of map character\n"
 	"                             scale(%%)\n"
 	"  -k, --clear-key-buf=FLAG clear key buffer:\n"
 	"                             ON, OFF\n"
@@ -165,18 +165,20 @@ void	init_arg( void )
 
 void	chk_arg( int argc, char **argv )
 {
-#if	(!HAVE_GETOPT_LONG && !HAVE_GETOPT_LONG)
+#if	(!HAVE_GETOPT && !HAVE_GETOPT_LONG)
 	long	n = 0;
 	char	*optarg;
-	long	optind = 1;
-#endif	/* (!HAVE_GETOPT_LONG && !HAVE_GETOPT_LONG) */
+	long	optind = argc;
+#endif	/* (!HAVE_GETOPT && !HAVE_GETOPT_LONG) */
 
 	if( argv == NULL )
 		return;
 
 	while( 1 ){
 		long	c;
+#if	HAVE_GETOPT_LONG
 		int	opt_idx;
+#endif	/* HAVE_GETOPT_LONG */
 
 #if	HAVE_GETOPT_LONG
 		c = getopt_long( argc, argv, STR_OPT, long_opt, &opt_idx );
@@ -184,6 +186,8 @@ void	chk_arg( int argc, char **argv )
 		c = getopt( argc, argv, STR_OPT );
 #else	/* HAVE_GETOPT_LONG */
 		n++;
+		if( n > argc - 1 )
+			break;
 		optarg = argv[n + 1];
 
 		if( argv[n][0] == '-' )
