@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.h,v 1.48 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: gmain.h,v 1.49 2007/02/04 17:41:35 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GMAIN_H
@@ -142,6 +142,9 @@ EXTERN bool_t	g_flg_cui;
 /* GUI ⡼ */
 EXTERN bool_t	g_flg_gui;
 
+/* եå̤γΨ */
+EXTERN rate_t	g_graph_scale_rate;
+
 /* Ϥɤɤफ? */
 EXTERN gui_key_kind_t	g_gui_key_kind;
 
