@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu.c,v 1.20 2007/02/02 14:09:32 bowkenken Exp $
+* $Id: imenu.c,v 1.23 2007/03/11 20:49:58 bowkenken Exp $
 ***************************************************************/
 
 #define	IMENU_C
@@ -658,6 +658,7 @@ long	menu_mbr_data(
 		if( flg_sel ){
 			draw_mbr_data( org_p, mbr_p, n, FALSE );
 			*page_n += exec_menu_edit_mbr_data( mbr_p, n );
+			*page_n += MBR_DATA_PAGE_MAX_N;
 			*page_n %= MBR_DATA_PAGE_MAX_N;
 			n = next_mbr_data( *page_n, n,
 					+-0, edit_kind );
@@ -682,6 +683,11 @@ long	menu_mbr_data(
 
 long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n )
 {
+	item_t	*item_head, *item;
+	equip_kind_t	eq_k;
+	long	item_n;
+	long	i;
+
 	switch( n ){
 	case DATA_N_NAME:
 		print_msg( FLG_MSG_NO_MORE_NEXT, MSG_GETS_MBR_NAME,
@@ -706,6 +712,57 @@ long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n )
 	case DATA_N_CLASS:
 		exec_menu_class( &(mbr->class_n) );
 		break;
+
+	case DATA_N_ITEM_00:
+	case DATA_N_ITEM_01:
+	case DATA_N_ITEM_02:
+	case DATA_N_ITEM_03:
+	case DATA_N_ITEM_04:
+	case DATA_N_ITEM_05:
+	case DATA_N_ITEM_06:
+	case DATA_N_ITEM_07:
+	case DATA_N_ITEM_08:
+	case DATA_N_ITEM_09:
+	case DATA_N_ITEM_10:
+	case DATA_N_ITEM_11:
+	case DATA_N_ITEM_12:
+	case DATA_N_ITEM_13:
+	case DATA_N_ITEM_14:
+	case DATA_N_ITEM_15:
+		item_n = n - DATA_N_ITEM_00;
+		item_head = get_mbr_item_asgn( mbr );
+		item = item_head->next;
+		for( i = 0; i < item_n; i++, item = item->next )
+			if( item == item_head )
+				break;
+
+		if( (i == item_n) && (item != item_head) )
+			chk_item_data( item );
+		break;
+
+	case DATA_N_EQUIP_WIELDING:
+	case DATA_N_EQUIP_SHIELD:
+	case DATA_N_EQUIP_BOW:
+	case DATA_N_EQUIP_ARW:
+	case DATA_N_EQUIP_HEAD:
+	case DATA_N_EQUIP_NECK:
+	case DATA_N_EQUIP_BODY:
+	case DATA_N_EQUIP_ABOUT_BODY:
+	case DATA_N_EQUIP_ARM:
+	case DATA_N_EQUIP_RIGHT_HAND:
+	case DATA_N_EQUIP_LEFT_HAND:
+	case DATA_N_EQUIP_FEET:
+	case DATA_N_EQUIP_LIGHT_SOURCE:
+		item = get_mbr_item_asgn_equip( mbr );
+		eq_k = (equip_kind_t)(EQUIP_KIND_NULL
+				+ (n - DATA_N_EQUIP_WIELDING));
+
+		if( item[eq_k].kind != ITEM_KIND_NULL )
+			chk_item_data( &(item[eq_k]) );
+		break;
+
+	case DATA_N_PREV_PAGE:
+		return -1;
 	case DATA_N_NEXT_PAGE:
 		return +1;
 	default:
@@ -3330,9 +3387,10 @@ char	*cb_menu_set_key( menu_t **pp, menu_t **dflt )
 {
 	char	*msg_key = MSG_GETS_SET_KEY_KEY;
 	static char	msg_cmd[WIN_MSG_DRAW_WIDTH + 1];
-	static char	buf_key[MACRO_MAX_LEN + 1];
+	static char	buf_key[MACRO_MAX_LEN + 1] = "";
 	static char	buf_cmd[MACRO_MAX_LEN + 1];
 	char	*prev_cmd;
+	long	len;
 	long	x, y;
 
 	/* key */
@@ -3341,46 +3399,43 @@ char	*cb_menu_set_key( menu_t **pp, menu_t **dflt )
 
 	x = str_len_draw( msg_key );
 	y = get_max_line() - 1;
-	if( game_gets( x, y, buf_key, MACRO_MAX_LEN, TRUE ) ){
-		long	len;
+	if( !game_gets( x, y, msg_key, buf_key, MACRO_MAX_LEN, TRUE ) )
+		return STR_MENU_CANCEL;
 
-		len = str_len_std( buf_key );
-		if( len >= 1 )
-			if( buf_key[len - 1] == '\n' )
-				buf_key[len - 1] = '\0';
+	len = str_len_std( buf_key );
+	if( len >= 1 )
+		if( buf_key[len - 1] == '\n' )
+			buf_key[len - 1] = '\0';
 
-		if( buf_key[0] == '\0' )
-			return STR_MENU_CANCEL;
-	} else {
+	if( buf_key[0] == '\0' )
 		return STR_MENU_CANCEL;
-	}
 
 	/* command */
 
 	prev_cmd = get_key_tab_cmd( buf_key );
-	if( prev_cmd == NULL )
+	if( prev_cmd == NULL ){
 		print_msg( FLG_NULL, MSG_GETS_SET_KEY_PREV, MSG_NULL );
-	else
+		str_nz_cpy( buf_cmd, "", MACRO_MAX_LEN );
+	} else {
 		print_msg( FLG_NULL, MSG_GETS_SET_KEY_PREV, prev_cmd );
+		str_nz_cpy( buf_cmd, prev_cmd, MACRO_MAX_LEN );
+	}
 
 	sprintf( msg_cmd, MSG_GETS_SET_KEY_CMD, MACRO_MAX_LEN );
 	print_msg( FLG_NULL, msg_cmd );
 
 	x = str_len_draw( msg_cmd );
 	y = get_max_line() - 1;
-	if( game_gets( x, y, buf_cmd, MACRO_MAX_LEN, TRUE ) ){
-		long	len;
+	if( !game_gets( x, y, msg_cmd, buf_cmd, MACRO_MAX_LEN, TRUE ) )
+		return STR_MENU_CANCEL;
 
-		len = str_len_std( buf_cmd );
-		if( len >= 1 )
-			if( buf_cmd[len - 1] == '\n' )
-				buf_cmd[len - 1] = '\0';
+	len = str_len_std( buf_cmd );
+	if( len >= 1 )
+		if( buf_cmd[len - 1] == '\n' )
+			buf_cmd[len - 1] = '\0';
 
-		if( buf_cmd[0] == '\0' )
-			return STR_MENU_CANCEL;
-	} else {
+	if( buf_cmd[0] == '\0' )
 		return STR_MENU_CANCEL;
-	}
 
 	/**/
 
@@ -3399,6 +3454,7 @@ char	*cb_menu_set_key_reg_macro( menu_t **pp, menu_t **dflt )
 	static char	buf_key[MACRO_MAX_LEN + 1];
 	char	*cmd;
 	long	x, y;
+	long	len;
 
 	/* key */
 
@@ -3406,19 +3462,16 @@ char	*cb_menu_set_key_reg_macro( menu_t **pp, menu_t **dflt )
 
 	x = str_len_draw( msg_key );
 	y = get_max_line() - 1;
-	if( game_gets( x, y, buf_key, MACRO_MAX_LEN, TRUE ) ){
-		long	len;
+	if( !game_gets( x, y, msg_key, buf_key, MACRO_MAX_LEN, TRUE ) )
+		return STR_MENU_CANCEL;
 
-		len = str_len_std( buf_key );
-		if( len >= 1 )
-			if( buf_key[len - 1] == '\n' )
-				buf_key[len - 1] = '\0';
+	len = str_len_std( buf_key );
+	if( len >= 1 )
+		if( buf_key[len - 1] == '\n' )
+			buf_key[len - 1] = '\0';
 
-		if( buf_key[0] == '\0' )
-			return STR_MENU_CANCEL;
-	} else {
+	if( buf_key[0] == '\0' )
 		return STR_MENU_CANCEL;
-	}
 
 	/* command */
 
@@ -3442,6 +3495,7 @@ char	*cb_menu_unset_key( menu_t **pp, menu_t **dflt )
 	char	*msg_key = MSG_GETS_UNSET_KEY_KEY;
 	static char	buf_key[MACRO_MAX_LEN + 1];
 	long	x, y;
+	long	len;
 
 	/* key */
 
@@ -3449,19 +3503,16 @@ char	*cb_menu_unset_key( menu_t **pp, menu_t **dflt )
 
 	x = str_len_draw( msg_key );
 	y = get_max_line() - 1;
-	if( game_gets( x, y, buf_key, MACRO_MAX_LEN, TRUE ) ){
-		long	len;
+	if( !game_gets( x, y, msg_key, buf_key, MACRO_MAX_LEN, TRUE ) )
+		return STR_MENU_CANCEL;
 
-		len = str_len_std( buf_key );
-		if( len >= 1 )
-			if( buf_key[len - 1] == '\n' )
-				buf_key[len - 1] = '\0';
+	len = str_len_std( buf_key );
+	if( len >= 1 )
+		if( buf_key[len - 1] == '\n' )
+			buf_key[len - 1] = '\0';
 
-		if( buf_key[0] == '\0' )
-			return STR_MENU_CANCEL;
-	} else {
+	if( buf_key[0] == '\0' )
 		return STR_MENU_CANCEL;
-	}
 
 	/**/
 
@@ -3498,7 +3549,7 @@ char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt )
 {
-	char	*msg = MSG_GETS_FUNC_EDIT;
+	char	msg[80 + 1];
 	static char	buf[MACRO_MAX_LEN + 1];
 	long	n;
 	long	x, y;
@@ -3508,10 +3559,12 @@ char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt )
 	y = get_max_line() - 1;
 	n = (long)((*pp)->arg);
 
+	sprintf( msg, MSG_GETS_FUNC_EDIT, MACRO_MAX_LEN );
 	print_msg( FLG_NULL, MSG_GETS_FUNC_PREV, get_func( n ) );
-	print_msg( FLG_NULL, msg, MACRO_MAX_LEN );
+	print_msg( FLG_NULL, msg );
 
-	if( !game_gets( x, y, buf, MACRO_MAX_LEN, TRUE ) )
+	str_nz_cpy( buf, get_func( n ), MACRO_MAX_LEN );
+	if( !game_gets( x, y, msg, buf, MACRO_MAX_LEN, TRUE ) )
 		return STR_MENU_CANCEL;
 
 	len = str_len_std( buf );
@@ -3789,6 +3842,7 @@ char	*menu_user_new_sub(
 	static char	buf_name[MENU_MSG_MAX_LEN + 1];
 	static char	buf_cmd[MACRO_MAX_LEN + 1];
 	long	x, y;
+	long	len;
 
 	/* name */
 
@@ -3796,19 +3850,16 @@ char	*menu_user_new_sub(
 
 	x = str_len_draw( msg_name );
 	y = get_max_line() - 1;
-	if( game_gets( x, y, buf_name, MENU_MSG_MAX_LEN, TRUE ) ){
-		long	len;
+	if( !game_gets( x, y, msg_name, buf_name, MENU_MSG_MAX_LEN, TRUE ) )
+		return STR_MENU_CANCEL;
 
-		len = str_len_std( buf_name );
-		if( len >= 1 )
-			if( buf_name[len - 1] == '\n' )
-				buf_name[len - 1] = '\0';
+	len = str_len_std( buf_name );
+	if( len >= 1 )
+		if( buf_name[len - 1] == '\n' )
+			buf_name[len - 1] = '\0';
 
-		if( buf_name[0] == '\0' )
-			return STR_MENU_CANCEL;
-	} else {
+	if( buf_name[0] == '\0' )
 		return STR_MENU_CANCEL;
-	}
 
 	/* command */
 
@@ -3820,24 +3871,25 @@ char	*menu_user_new_sub(
 
 		str_nz_cpy( buf_cmd, macro, MACRO_MAX_LEN );
 	} else {
+		long	len;
+
 		sprintf( msg_cmd, MSG_GETS_USER_MENU_CMD, MACRO_MAX_LEN );
 		print_msg( FLG_NULL, MSG_S, msg_cmd );
 
 		x = str_len_draw( msg_cmd );
 		y = get_max_line() - 1;
-		if( game_gets( x, y, buf_cmd, MACRO_MAX_LEN, TRUE ) ){
-			long	len;
-
-			len = str_len_std( buf_cmd );
-			if( len >= 1 )
-				if( buf_cmd[len - 1] == '\n' )
-					buf_cmd[len - 1] = '\0';
-
-			if( buf_cmd[0] == '\0' )
-				return STR_MENU_CANCEL;
-		} else {
+		if( !game_gets( x, y, msg_cmd,
+				buf_cmd, MACRO_MAX_LEN, TRUE ) ){
 			return STR_MENU_CANCEL;
 		}
+
+		len = str_len_std( buf_cmd );
+		if( len >= 1 )
+			if( buf_cmd[len - 1] == '\n' )
+				buf_cmd[len - 1] = '\0';
+
+		if( buf_cmd[0] == '\0' )
+			return STR_MENU_CANCEL;
 	}
 
 	/**/
