@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: inc.h,v 1.31 2007/02/11 03:42:23 bowkenken Exp $
+* $Id: inc.h,v 1.36 2007/03/17 21:57:07 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	INC_H
@@ -197,10 +197,12 @@
 # ifdef	D_DOS
 #  include	<windows.h>
 #  include	<conio.h>
-#  ifdef	D_WIN
-#   include	"../lnl-dos/stdafx.h"
-#  else
-#   include	"lnl-dos/stdafx.h"
+#  ifndef	D_WS
+#   ifdef	D_WIN
+#    include	"../lnl-dos/stdafx.h"
+#   else
+#    include	"lnl-dos/stdafx.h"
+#   endif
 #  endif
 # endif
 
@@ -215,7 +217,7 @@
 /*#include	"turn.h"*/
 /*#include	"dun.h"*/
 #include	"town.h"
-/*#include	"item.h"*/
+#include	"item.h"
 #include	"spell.h"
 /*#include	"chr.h"*/
 /*#include	"party.h"*/
@@ -237,7 +239,7 @@
 #include	"turn-prot.h"
 #include	"dun-prot.h"
 /*#include	"town-prot.h"*/
-/*#include	"item-prot.h"*/
+#include	"item-prot.h"
 #include	"spell-prot.h"
 #include	"chr-prot.h"
 #include	"party-prot.h"
@@ -442,6 +444,7 @@
 #include	"gmain.h"
 /*#include	"misc.h"*/
 #include	"turn.h"
+#include	"dun.h"
 #include	"town.h"
 #include	"item.h"
 #include	"spell.h"
@@ -1869,6 +1872,75 @@
 
 /***************************************************************/
 
+#ifdef	GUI_INPUT_STRING_CPP
+
+#include	"gmain.h"
+#include	"misc.h"
+/*#include	"turn.h"*/
+/*#include	"dun.h"*/
+/*#include	"town.h"*/
+/*#include	"item.h"*/
+/*#include	"spell.h"*/
+/*#include	"chr.h"*/
+/*#include	"party.h"*/
+/*#include	"mnstr.h"*/
+/*#include	"pet.h"*/
+/*#include	"fight.h"*/
+/*#include	"fx.h"*/
+/*#include	"trap.h"*/
+#include	"draw.h"
+/*#include	"curs.h"*/
+/*#include	"menu.h"*/
+/*#include	"amenu.h"*/
+/*#include	"request.h"*/
+/*#include	"gfile.h"*/
+/*#include	"msg.h"*/
+/*#include	"ver.h"*/
+/*#include	"gmain-prot.h"*/
+/*#include	"misc-prot.h"*/
+/*#include	"turn-prot.h"*/
+/*#include	"dun-prot.h"*/
+/*#include	"town-prot.h"*/
+/*#include	"item-prot.h"*/
+/*#include	"spell-prot.h"*/
+/*#include	"chr-prot.h"*/
+/*#include	"party-prot.h"*/
+/*#include	"mnstr-prot.h"*/
+/*#include	"pet-prot.h"*/
+/*#include	"fight-prot.h"*/
+/*#include	"fx-prot.h"*/
+/*#include	"trap-prot.h"*/
+#include	"draw-prot.h"
+/*#include	"curs-prot.h"*/
+/*#include	"menu-prot.h"*/
+/*#include	"mmenu-prot.h"*/
+/*#include	"imenu-prot.h"*/
+/*#include	"tmenu-prot.h"*/
+/*#include	"amenu-prot.h"*/
+/*#include	"request-prot.h"*/
+/*#include	"gfile-prot.h"*/
+/*#include	"msg-prot.h"*/
+
+#ifdef D_WS
+//@@@
+//# include <WScom.h>
+//# include <WSDappDev.h>
+//# include <WSCmainWindow.h>
+//# include <WSCfunctionList.h>
+//# include <WSCbase.h>
+//# include <WSCwindow.h>
+# include <WSCvifield.h>
+#endif // D_WS
+
+#ifdef D_GTK
+# include <gtk/gtk.h>
+# include "GuiMisc.h"
+#endif // D_GTK
+
+#endif	/* GUI_INPUT_STRING_CPP */
+
+/***************************************************************/
+
 #if	defined( D_WIN )
 # include	"main-win-prot.h"
 #elif	defined( D_DOS )
