@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: item.h,v 1.87 2007/01/11 17:31:34 bowkenken Exp $
+* $Id: item.h,v 1.89 2007/03/11 20:27:12 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	ITEM_H
@@ -258,7 +258,9 @@ typedef enum {
 	EQUIP_KIND_LEFT_HAND,
 	EQUIP_KIND_FEET,
 	EQUIP_KIND_LIGHT_SOURCE,
+
 	EQUIP_KIND_MAX_N,
+	EQUIP_KIND_NULL = EQUIP_KIND_WIELDING,
 } equip_kind_t;
 
 /* μ */
@@ -1440,6 +1442,8 @@ typedef struct {
 typedef struct item_t {
 	/*  */
 	struct item_t	*next, *prev;
+	/* ʬե饰 */
+	bool_t	flg_garbage;
 
 	/* ̾ */
 	char	name[ITEM_NAME_MAX_LEN + 1];
