@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mmenu.c,v 1.15 2007/02/02 14:09:32 bowkenken Exp $
+* $Id: mmenu.c,v 1.18 2007/03/17 21:57:07 bowkenken Exp $
 ***************************************************************/
 
 #define	MMENU_C
@@ -491,6 +491,8 @@ char	*cb_menu_mark( menu_t **pp, menu_t **dflt )
 
 	set_menu_dflt_main( *pp );
 
+	*pp = NULL;
+
 	trgt_kind_1 = TRGT_KIND_NULL;
 	trgt_kind_2 = TRGT_KIND_NULL;
 
@@ -1091,19 +1093,24 @@ bool_t	menu_mark_square_pos( pos_t pos )
 		case CASE_EXEC:
 			return FALSE;
 			break;
+		case CASE_ENTER:
 		case CASE_CRSR_UP:
+		case '-':
 			sq->dir_y = -1;
 			flg_loop = FALSE;
 			break;
 		case CASE_CRSR_DOWN:
+		case '+':
 			sq->dir_y = +1;
 			flg_loop = FALSE;
 			break;
 		case CASE_CRSR_LEFT:
+		case '/':
 			sq->dir_x = -1;
 			flg_loop = FALSE;
 			break;
 		case CASE_CRSR_RIGHT:
+		case '*':
 			sq->dir_x = +1;
 			flg_loop = FALSE;
 			break;
@@ -2375,7 +2382,8 @@ char	*cb_menu_fight( menu_t **pp, menu_t **dflt )
 
 char	*cb_menu_load( menu_t **pp, menu_t **dflt )
 {
-	menu_load( TRUE );
+	if( menu_load( TRUE ) )
+		reset_all( TRUE );
 
 	return STR_MENU_CANCEL;
 }
@@ -2421,7 +2429,13 @@ bool_t	menu_load( bool_t flg_txt )
 
 bool_t	menu_save( bool_t flg_txt )
 {
-	long	n;
+	return menu_save_n( flg_txt, SAVE_N_SEL );
+}
+
+/**/
+
+bool_t	menu_save_n( bool_t flg_txt, long save_n )
+{
 	ask_t	ask;
 
 	if( !flg_txt && g_flg_no_save ){
@@ -2429,20 +2443,34 @@ bool_t	menu_save( bool_t flg_txt )
 		return FALSE;
 	}
 
-	n = menu_sel_save_load( TRUE, flg_txt );
-	if( n <= -1 )
-		return FALSE;
+	if( save_n == SAVE_N_SEL ){
+		save_n = menu_sel_save_load( TRUE, flg_txt );
 
-	ask = exec_menu_ask( MSG_TTL_MENU_ASK_SAVE, ASK_NO, TRUE );
-	if( ask != ASK_YES )
-		return FALSE;
+		if( save_n == SAVE_N_AUTO ){
+			print_msg( FLG_MSG_ERR,
+					MSG_ERR_MENU_SAVE_N_SEL_AUTO );
+			return FALSE;
+		}
+
+		if( save_n == SAVE_N_SEL )
+			return FALSE;
+	}
+
+	if( save_n != SAVE_N_AUTO ){
+		ask = exec_menu_ask( MSG_TTL_MENU_ASK_SAVE, ASK_NO, TRUE );
+		if( ask != ASK_YES )
+			return FALSE;
+	}
 
 	save_dun();
 	save_town();
 	save_game_conf();
-	save_game_data( flg_txt, n );
+	save_game_data( flg_txt, save_n );
 
-	print_msg( FLG_NULL, MSG_MENU_SAVE_SUCCESS );
+	if( flg_txt )
+		print_msg( FLG_NULL, MSG_MENU_SAVE_SUCCESS_TXT, save_n );
+	else
+		print_msg( FLG_NULL, MSG_MENU_SAVE_SUCCESS_BIN, save_n );
 
 	return TRUE;
 }
@@ -2531,10 +2559,10 @@ long	menu_sel_save_load( bool_t flg_save, bool_t flg_txt )
 				return g_sel_save_load_n;
 		}
 
-		return -1;
+		return SAVE_N_SEL;
 	}
 
-	return -1;
+	return SAVE_N_SEL;
 }
 
 /**/
@@ -2592,6 +2620,13 @@ void	set_flg_no_save( bool_t flg )
 
 /**/
 
+bool_t	get_flg_no_save( void )
+{
+	return g_flg_no_save;
+}
+
+/**/
+
 bool_t	exec_menu_identify_item( mbr_t *mbr )
 {
 	party_t	*pty = get_party();
