@@ -51,7 +51,6 @@ void	mnstr_drop_gold( mnstr_t *p );
 void	mnstr_drop_bone( mnstr_t *p );
 void	mnstr_drop_item( mnstr_t *p );
 void	set_find_all_mnstr( void );
-long	get_party_dun_max_lev( void );
 void	print_ls_mnstr( void );
 mnstr_kind_t	get_npc_kind_randm( void );
 char	*get_mnstr_mjr_name( char mjr );
@@ -66,7 +65,12 @@ mnstr_tab_t	*get_mnstr_tab_friendly( void );
 mnstr_tab_t	*get_towner_tab_rand( void );
 mnstr_lev_tab_t	*get_mnstr_lev_tab( mnstr_kind_t mnstr_kind, long dun_lev );
 void	ins_ls_mnstr( mnstr_t *ls, mnstr_t *p );
-void	exp_chr_mnstr( chr_t *chr, long exp, bool_t flg_print_lev );
+void	exp_chr_mnstr(
+	chr_t *chr,
+	long exp,
+	bool_t flg_set_max,
+	bool_t flg_print_lev
+);
 long	calc_mnstr_exp( mnstr_t *p, long dun_lev );
 long	calc_mnstr_abl_lev( long dun_lev, abl_kind_t k, mnstr_tab_t *tab );
 rate_t	calc_mnstr_group_rate( long group_n );
