@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: msg.c,v 1.30 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: msg.c,v 1.31 2007/03/12 18:39:54 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -163,6 +163,7 @@ void	init_msg( void )
 {
 	bool_t	flg_exit;
 	char	*lang;
+	long	lang_tab_kind;
 	long	m;
 	long	k;
 	long	i;
@@ -178,12 +179,14 @@ void	init_msg( void )
 	/* Ķѿǻꤵ줿μõ */
 
 	g_lang_kind = LANG_KIND_MAX_N;
+	lang_tab_kind = 0;
 	for( k = 0; k < LANG_TAB_MAX_N; k++ ){
 		if( lang_tab[k].id == NULL )
 			break;
 
 		if( strcmp( lang, lang_tab[k].id ) == 0 ){
 			g_lang_kind = lang_tab[k].kind;
+			lang_tab_kind = k;
 			break;
 		}
 	}
@@ -221,9 +224,11 @@ void	init_msg( void )
 			/* åƤ */
 			s = all_lang_msg[g_lang_kind][m].s;
 			print_err( STR_ERR_REDEFINED_MSG,
-					lang_tab[g_lang_kind].id, m, s );
+					lang_tab[lang_tab_kind].id, m, s );
 			flg_exit = TRUE;
 		}
+
+		/* å򥳥ԡ */
 		ary_msg[m] = all_lang_msg[g_lang_kind][i].s;
 		flg_msg_def[m] = TRUE;
 	}
@@ -234,7 +239,7 @@ void	init_msg( void )
 		if( !flg_msg_def[m] ){
 			/* åƤʤ */
 			print_err( STR_ERR_NOT_DEFINED_MSG,
-					lang_tab[g_lang_kind].id, m );
+					lang_tab[lang_tab_kind].id, m );
 			flg_exit = TRUE;
 		}
 	}
