@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.183 2007/02/06 17:30:27 bowkenken Exp $
+* $Id: party.c,v 1.186 2007/03/01 23:30:04 bowkenken Exp $
 ***************************************************************/
 
 #define	PARTY_C
@@ -213,7 +213,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[0], "<///BLADE//}===o", 'B', race,
 			MALE, CLASS_N_FIGHTER, 0 );
-	str_nz_cpy( ls_mbr[0]->graph_name, "mon_150.gif",
+	str_nz_cpy( ls_mbr[0]->graph_name, "mon_090.gif",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_DWARF;
@@ -229,7 +229,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
-	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
+	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -237,7 +237,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
-	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
+	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_VIVID;
@@ -245,7 +245,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
-	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
+	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_ELF;
@@ -253,7 +253,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
-	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
+	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -261,7 +261,7 @@ void	init_party_dflt( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
-	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
+	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -444,7 +444,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HALF_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[2], "<---ELSIE----<<<", 'E', race,
 			MALE, CLASS_N_HUNTER, 2 );
-	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.bmp",
+	str_nz_cpy( ls_mbr[2]->graph_name, "mon_042.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -452,7 +452,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_HUMAN, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[3], "+-==CECILE=====X", 'C', race,
 			FEMALE, CLASS_N_PRIEST, 3 );
-	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.bmp",
+	str_nz_cpy( ls_mbr[3]->graph_name, "mon_214r.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_VIVID;
@@ -460,7 +460,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_VIVID, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[4], "m-o HALLE  <<<)=", 'H', race,
 			MALE, CLASS_N_THIEF, 4 );
-	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.bmp",
+	str_nz_cpy( ls_mbr[4]->graph_name, "mon_212r.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_ELF;
@@ -468,7 +468,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_MAIN_RACE_ELF, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[5], "O>==BEAUT====---", 'U', race,
 			FEMALE, CLASS_N_WIZARD, 5 );
-	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.bmp",
+	str_nz_cpy( ls_mbr[5]->graph_name, "mon_018.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -476,7 +476,7 @@ void	init_party_debug( void )
 	str_nz_cpy( race.name, MSG_RACE_NAME_VEGE, RACE_NAME_MAX_LEN );
 	new_mbr( ls_mbr[6], "====GOKOU=======", 'G', race,
 			MALE, CLASS_N_MONK, 6 );
-	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.bmp",
+	str_nz_cpy( ls_mbr[6]->graph_name, "mon_216r.png",
 			FILE_NAME_MAX_LEN );
 
 	race.main = MAIN_RACE_HUMAN;
@@ -1533,8 +1533,6 @@ void	move_phase_party( void )
 
 	for( i = 0; i < MBR_MAX_N; i++ )
 		move_phase_chr( party.mbr[i] );
-
-	draw_party();
 }
 
 /**/
