@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.156 2007/01/11 17:31:35 bowkenken Exp $
+* $Id: spell.c,v 1.158 2007/03/18 05:45:53 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -892,15 +892,25 @@ void	chr_cast_spell_blast(
 	long	nx, ny;
 	long	xx, yy;
 	bool_t	flg_actual;
+	chr_kind_t	kind;
 
 	if( chr == NULL )
 		return;
 	if( tab == NULL )
 		return;
 
+	if( trgt_kind == TRGT_KIND_MBR )
+		kind = CHR_KIND_MBR;
+	else if( trgt_kind == TRGT_KIND_MNSTR )
+		kind = CHR_KIND_MNSTR;
+	else if( trgt_kind == TRGT_KIND_MNSTR_NULL )
+		kind = CHR_KIND_MNSTR;
+	else
+		kind = CHR_KIND_NULL;
+
 	blast = get_blast_spell( tab->kind );
 	blast_str = get_spell_vfx_str( tab->kind );
-	draw_blast( x, y, blast, blast_str );
+	draw_blast( kind, x, y, blast, blast_str );
 	wait_clock( ANIM_FRAME_N_BLAST_STD );
 
 	flg_actual = chk_flg( get_flg_party(), FLG_PARTY_ACTUAL_FIGHTING );
@@ -958,7 +968,7 @@ void	chr_cast_spell_blast(
 			chr_cast_spell_sub( chr, flg_item, tab, rate,
 					xx, yy, trgt_kind, p );
 
-			draw_blast( x, y, blast, blast_str );
+			draw_blast( kind, x, y, blast, blast_str );
 		}
 	}
 
@@ -1423,10 +1433,8 @@ void	chr_cast_spell_sub(
 
 	/* ɸ˻̤äƤ뤫å */
 
-	if( flg_chr ){
-		if( !chk_find_chr( chr, d_p ) )
-			return;
-	} else {
+	if( !flg_chr || (trgt_kind == TRGT_KIND_MNSTR_NULL)
+			||  (trgt_kind != TRGT_KIND_POS) ){
 		pos_t	pos1, pos2;
 
 		pos1.x = chr->x;
@@ -1435,6 +1443,9 @@ void	chr_cast_spell_sub(
 		pos2.y = y;
 		if( !chk_find( &pos1, &pos2 ) )
 			return;
+	} else {
+		if( !chk_find_chr( chr, d_p ) )
+			return;
 	}
 
 	/* ʤ󥹥뤫å */
